# WRTS.py (or wrts or wrtsapi)
*renaming wrts to studygo is like the rebranding of twitter to X*

No docs *yet*.

oh yeah btw disclaimer: not my responsibility if you do something dumb dumb

## TODO
[ ] Add "PublicSession" class
[ ] Add functions for changing account settings
[ ] Add support for Groups
[ ] Add support for Books
[ ] Add more exercise types
[ ] Parse more objects
[ ] Make documentation